@@ -199,7 +199,7 @@ def vol_to_surf(
             volsize[i]=0
         elif Vols[-1].ndim == 3:
             volsize[i]=1
-        else: 
+        else:
             volsize[i]=Vols[-1].shape[3]
 
 
@@ -225,13 +225,13 @@ def vol_to_surf(
             if ignore_zeros:
                 X[X==0] = np.nan
             data = X[indices[:,:,0],indices[:,:,1],indices[:,:,2]]
-            if data.ndim == 2: 
+            if data.ndim == 2:
                 data = data.reshape(data.shape + (1,))
             # Determine the right statistics - if function - call it
             if stats=='nanmean':
                 mapped_data[:,index[v]:index[v+1]] = np.nanmean(data,axis=0)
             elif stats=='mode':
-                mapped_data[:,index[v]:index[v+1]],_ = ss.mode(data,axis=0)
+                mapped_data[:,index[v]:index[v+1]],_ = ss.mode(data,axis=0,keepdims=False)
             elif callable(stats):
                 mapped_data[:,index[v]:index[v+1]] = stats(data)
 
@@ -399,7 +399,7 @@ def get_gifti_column_names(gifti):
                 names.append(gifti.darrays[n].meta.data[i].value)
     return names
 
-def get_gifti_colortable(gifti,ignore_0=True):
+def get_gifti_colortable(gifti):
     """Returns the RGBA color table and matplotlib cmap from gifti object (*.label.gii)
 
     Args:
@@ -420,11 +420,7 @@ def get_gifti_colortable(gifti,ignore_0=True):
     for i,label in enumerate(labels):
         rgba[i,] = labels[i].rgba
 
-    if ignore_0:
-        rgba = rgba[1:]
-        labels = labels[1:]
-
-    cmap = LinearSegmentedColormap.from_list('mylist', rgba, N=len(rgba))
+    cmap = ListedColormap(rgba)
     mpl.cm.unregister_cmap("mycolormap")
     mpl.cm.register_cmap("mycolormap", cmap)
 
@@ -536,12 +532,14 @@ def plot(
         underscale (array-like)
             Colorscale [min, max] for the underlay (default: [-1, 0.5])
         overlay_type (str)
-            'func': functional activation 'label': categories 'rgb': RGB values (default: func)
+            'func': functional activation (default)
+            'label': categories
+            'rgb': RGB(A) values (0-1) directly specified. Alpha is optional
         threshold (scalar or array-like)
             Threshold for functional overlay. If one value is given, it is used as a positive threshold.
             If two values are given, an positive and negative threshold is used.
         cmap (str)
-            Matplotlib colormap used for overlay (defaults to 'jet' if none given)
+            A Matplotlib colormap or an equivalent Nx3 or Nx4 floating point array (N rgb or rgba values). (defaults to 'jet' if none given)
         label_names (list)
             labelnames (default is None - extracts from .label.gii )
         borders (str)
@@ -601,37 +599,46 @@ def plot(
     if type(data) is np.ndarray:
         data_arr = np.copy(data)
 
-    # If 2d-array, take the first column only
-    if data_arr.ndim>1:
-        data_arr = data_arr[:,0]
-    # depending on data type - type cast into int
-    if overlay_type=='label':
-        i = np.isnan(data_arr)
-        data_arr = data_arr.astype(int)
-        data_arr[i]=0
-
-    # create label names if they don't exist
-    if overlay_type=='label' and label_names is None:
-        num_labels = len(np.unique(data_arr))
-        label_names = []
-        # check for 0 labels
-        zero_label = 0 in data_arr
-        idx = 1
-        if zero_label:
-            idx = 0
-        for i in range(num_labels):
-            label_names.append("label-{:02d}".format(i + idx))
-
     # decide whether to map to faces
     if (render=='plotly'):
         mapfac=None    # Don't map to faces
     else:
         mapfac = faces # Map to faces
 
-    # map the overlay to colors:
-    overlay_color, cmap, cscale = _map_color(data=data_arr,
+    # Determine foreground color depending on type
+    if overlay_type=='label':
+        # If 2d-array, take the first column only
+        if data_arr.ndim>1:
+            data_arr = data_arr[:,0]
+        i = np.isnan(data_arr)
+        data_arr = data_arr.astype(int)
+        data_arr[i]=0
+
+        # create label names if they don't exist
+        if label_names is None:
+            label_names = [f"L-{i:02d}" for i in range(data_arr.max()+1)]
+        # map the overlay to colors:
+        overlay_color, cmap, cscale = _map_color(data=data_arr,
             faces = mapfac, cscale=cscale,
             cmap=cmap, threshold=threshold)
+    elif overlay_type=='func':
+        if data_arr.ndim>1:
+            data_arr = data_arr[:,0]
+        # map the overlay to colors:
+        overlay_color, cmap, cscale = _map_color(data=data_arr,
+            faces = mapfac, cscale=cscale,
+            cmap=cmap, threshold=threshold)
+    elif overlay_type=='rgb':
+        if mapfac is not None:
+            data  = _map_to_face(data,mapfac)
+        if data.shape[1]==3:
+            overlay_color = np.c_[data,np.ones(data.shape[0],1)]
+
+        elif data.shape[1]==4:
+            overlay_color = data[:,0:4]
+            alpha = data[:,3:4]
+        else:
+            raise(NameError('for RGB(A), the data needs to have 3 or 4 columns'))
 
     # Load underlay and assign color
     if type(underlay) is not np.ndarray:
@@ -660,17 +667,19 @@ def plot(
         # set up colorbar
         if colorbar:
             if overlay_type=='label':
-                cbar = _colorbar_label(ax, cmap, cscale, cbar_tick_format, label_names)
+                cbar = _colorbar_label(ax, cmap, cbar_tick_format, label_names)
             elif overlay_type=='func':
                 cbar = _colorbar_func(ax, cmap, cscale, cbar_tick_format)
     elif render == 'plotly':
         if hover == 'auto':
             if overlay_type=='func':
-                textlabel = _make_labels(data_arr,cbar_tick_format)
+                textlabel = _make_labels(data_arr,'{:' + cbar_tick_format[1:] + '}')
             if overlay_type=='label':
                 textlabel = _make_labels(data_arr,label_names)
+            if overlay_type=='rgb':
+                textlabel = _make_labels(data_arr,'({:.2f},{:.2f},{:.2f})')
         if hover == 'value':
-            textlabel = _make_labels(data_arr,cbar_tick_format)
+            textlabel = _make_labels(data_arr,'{:' + cbar_tick_format[1:] + '}')
         elif hover is None:
             textlabel=None
 
@@ -681,6 +690,16 @@ def plot(
 
     return ax
 
+def _map_to_face(data,faces):
+    numFaces = faces.shape[0]
+    face_value = np.zeros((3,numFaces,4),dtype = data.dtype)
+    for i in range(3):
+        face_value[i,:,:] = data[faces[:,i],:]
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=RuntimeWarning)
+        face_value = np.nanmean(face_value, axis=0)
+    return face_value
+
 
 def _map_color(
     data,
@@ -701,12 +720,15 @@ def _map_color(
         cscale (array like)
             (min,max) of the scaling of the data
         cmap (str, or matplotlib.colors.Colormap)
-            The Matplotlib colormap
+            The Matplotlib colormap an equivalent Nx3 or Nx4 floating point array (N rgb or rgba values).
         threshold (array like)
             (lower, upper) threshold for data display -
              only data x<lower and x>upper will be plotted
             if one value is given (-inf) is assumed for the lower
-
+    Returns:
+        color_data(ndarray): N x 4 ndarray
+        cmap
+        cscale
     """
     # if scale not given, find it
     if cscale is None:
@@ -731,7 +753,7 @@ def _map_color(
             face_value[i,:] = data[faces[:,i]]
 
         if data.dtype.kind == 'i':
-            value,_ = ss.mode(face_value,axis=0)
+            value,_ = ss.mode(face_value,axis=0,keepdims=False)
             value = value.reshape((numFaces,))
         else:
             with warnings.catch_warnings():
@@ -916,7 +938,10 @@ def _make_labels(data,labelstr):
     labels = np.empty((data.shape[0],),dtype=np.object)
     if type(labelstr) is str:
         for i in range(numvert):
-            labels[i]=f"{data[i]:{labelstr[1:]}}"
+            if data.ndim==1:
+                labels[i]=labelstr.format(data[i])
+            else:
+                labels[i]=labelstr.format(*data[i])
     else:
         for i in range(numvert):
             labels[i]=labelstr[data[i]]
@@ -925,7 +950,6 @@ def _make_labels(data,labelstr):
 def _colorbar_label(
     ax,
     cmap,
-    cscale,
     cbar_tick_format,
     label_names
     ):
@@ -936,8 +960,6 @@ def _colorbar_label(
             Pre-existing axes for the plot.
         cmap (str, or matplotlib.colors.Colormap)
             The Matplotlib colormap
-        cscale (array like)
-            (min,max) of the scaling of the data
         cbar_tick_format : str, optional
             Controls how to format the tick labels of the colorbar.
             Ex: use "%i" to display as integers.
@@ -949,16 +971,12 @@ def _colorbar_label(
         cbar (matplotlib.colorbar)
             Colorbar object
     """
-    # check if there is a 0 label and adjust colorbar accordingly
-    if cscale[0]==0:
-        cmap.N = cmap.N-1
-        label_names = label_names[1:]
-    # set up colorbar
+    N = len(label_names) # Length of the colormap
     cax, _ = make_axes(ax, location='right', fraction=.15,
                         shrink=.5, pad=.0, aspect=10.)
-    norm = Normalize(vmin=cscale[0], vmax=cscale[1])
-    ticks = np.arange(1,len(label_names)+1)+0.5
-    bounds = np.arange(1,len(label_names)+2)
+    norm = Normalize(vmin=0, vmax=cmap.N)
+    ticks = np.arange(0,N)+0.5
+    bounds = np.arange(0,N+1)
     proxy_mappable = ScalarMappable(cmap=cmap, norm=norm)
     cbar = plt.colorbar(
         proxy_mappable, cax=cax, ticks=ticks,
